==> SciDataTool-2.3.1.tar.gz: SciDataTool-2.3.1/SciDataTool/GUI/Resources/SDT_rc.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 5.15.2
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore

qt_resource_data = b"\
\x00\x00\x01q\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\
\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\
\x9c\x18\x00\x00\x01\x06IDATXGc\x18\x05\xa3\
`(\x01\x1d \x9e\x04\xa5\x07\x04\x80,\xff\xcf\xcc\xcc\
\xfc\xdf\xc6\x91\xf7?\x94OW\xc7\x80\x1d\x00\xc2\x8c\x8c\
\x8c`\x1a\x88\xb7C\xc5\xe9\xe2\x10\xb8\x03\xb0`\x90C\
\xc8r\x04\x13\x94\xa6\x14x\x00q\x1a\x84I\x1a`\x86\
\xd2\xc4\x00O 6\x870Q\x010J\x184u9\
\xcd\xdf\xbc\xfa#\x0c\xe4\x82\xd4=\x06\xe2W 9j\
\x02|Q\x80\x8e\x89\x8e\x12jE\x01: :Jh\
\xe5\x00\x06]C\xce\x5c E\xd5\x1cBJ\x14\xa0g\
U\x9c\x8e\xa0Y\x08\xfc\xff\x0f\xb2\x1b\x0c\xf0F\x07\xcd\
\x1c@,\xa0\x99\x03@Y\x13\x0av\x00\xf1,\x08\x13\
\x13\xd0\xcc\x01\x06\xa6\x1c j2\x10\x97\x02\xf1\x15\x10\
\x87R@R\x22\x04b\x90z\x82\x80\x16!\x00\x0ar\
\x90\xcfq\x06;\xb9\x00g\x08\xd0\xab\x8a\xc6\xe9\x80\xe0\
\x18>\x10Ms\x80/\x0d\x10\x15\xdf\xd8\x00\xa5i\x80\
f\xf1\x8d\x0d\x80C\x00\x14\xdf\x8e\x1e\x03\xd3$\x03Y\
FwKG\xc1(\xa01``\x00\x00\x1a\xf6lp\
\xfcO\xe9\xd3\x00\x00\x00\x00IEND\xaeB`\x82\
\
"

qt_resource_name = b"\
\x00\x06\
\x07\x03}\xc3\
\x00i\
\x00m\x00a\x00g\x00e\x00s\
\x00\x04\
\x00\x06\xfa^\
\x00i\
\x00c\x00o\x00n\
\x00\x0d\
\x07*\xd6G\
\x00p\
\x00l\x00a\x00y\x00-\x003\x002\x00p\x00x\x00.\x00p\x00n\x00g\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x03\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x12\x00\x02\x00\x00\x00\x01\x00\x00\x00\x04\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00 \x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x7f\xc1}\x1fz\
"


def qInitResources():
    QtCore.qRegisterResourceData(
        0x03, qt_resource_struct, qt_resource_name, qt_resource_data
    )


def qCleanupResources():
    QtCore.qUnregisterResourceData(
        0x03, qt_resource_struct, qt_resource_name, qt_resource_data
    )


qInitResources()

==> SciDataTool-2.3.14.tar.gz: SciDataTool-2.3.14/SciDataTool/GUI/Resources/SDT_rc.py <==
# Resource object code (Python 3)
# Created by: object code
# Created by: The Resource Compiler for Qt version 5.15.2
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore

qt_resource_data = b"\
\x00\x00\x01q\
\x89\
PNG\x0d\x0a\x1a\x0a\x00\x00\x00\x0dIHDR\x00\
\x00\x00 \x00\x00\x00 \x08\x06\x00\x00\x00szz\xf4\
\x00\x00\x00\x01sRGB\x00\xae\xce\x1c\xe9\x00\x00\x00\
\x04gAMA\x00\x00\xb1\x8f\x0b\xfca\x05\x00\x00\x00\
\x09pHYs\x00\x00\x0b\x13\x00\x00\x0b\x13\x01\x00\x9a\
\x9c\x18\x00\x00\x01\x06IDATXGc\x18\x05\xa3\
`(\x01\x1d \x9e\x04\xa5\x07\x04\x80,\xff\xcf\xcc\xcc\
\xfc\xdf\xc6\x91\xf7?\x94OW\xc7\x80\x1d\x00\xc2\x8c\x8c\
\x8c`\x1a\x88\xb7C\xc5\xe9\xe2\x10\xb8\x03\xb0`\x90C\
\xc8r\x04\x13\x94\xa6\x14x\x00q\x1a\x84I\x1a`\x86\
\xd2\xc4\x00O 6\x870Q\x010J\x184u9\
\xcd\xdf\xbc\xfa#\x0c\xe4\x82\xd4=\x06\xe2W 9j\
\x02|Q\x80\x8e\x89\x8e\x12jE\x01: :Jh\
\xe5\x00\x06]C\xce\x5c E\xd5\x1cBJ\x14\xa0g\
U\x9c\x8e\xa0Y\x08\xfc\xff\x0f\xb2\x1b\x0c\xf0F\x07\xcd\
\x1c@,\xa0\x99\x03@Y\x13\x0av\x00\xf1,\x08\x13\
\x13\xd0\xcc\x01\x06\xa6\x1c j2\x10\x97\x02\xf1\x15\x10\
\x87R@R\x22\x04b\x90z\x82\x80\x16!\x00\x0ar\
\x90\xcfq\x06;\xb9\x00g\x08\xd0\xab\x8a\xc6\xe9\x80\xe0\
\x18>\x10Ms\x80/\x0d\x10\x15\xdf\xd8\x00\xa5i\x80\
f\xf1\x8d\x0d\x80C\x00\x14\xdf\x8e\x1e\x03\xd3$\x03Y\
FwKG\xc1(\xa01``\x00\x00\x1a\xf6lp\
\xfcO\xe9\xd3\x00\x00\x00\x00IEND\xaeB`\x82\
\
"

qt_resource_name = b"\
\x00\x06\
\x07\x03}\xc3\
\x00i\
\x00m\x00a\x00g\x00e\x00s\
\x00\x04\
\x00\x06\xfa^\
\x00i\
\x00c\x00o\x00n\
\x00\x11\
\x06\x99\x08\xc7\
\x00p\
\x00l\x00a\x00y\x00-\x003\x002\x00p\x00x\x00_\x00S\x00D\x00T\x00.\x00p\x00n\x00g\
\
"

qt_resource_struct = b"\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x01\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x02\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x00\x00\x02\x00\x00\x00\x01\x00\x00\x00\x03\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00\x12\x00\x02\x00\x00\x00\x01\x00\x00\x00\x04\
\x00\x00\x00\x00\x00\x00\x00\x00\
\x00\x00\x00 \x00\x00\x00\x00\x00\x01\x00\x00\x00\x00\
\x00\x00\x01\x7f\xc1}\x1fz\
"


def qInitResources():
    QtCore.qRegisterResourceData(
        0x03, qt_resource_struct, qt_resource_name, qt_resource_data
    )


def qCleanupResources():
    QtCore.qUnregisterResourceData(
        0x03, qt_resource_struct, qt_resource_name, qt_resource_data
    )


qInitResources()
